#!/bin/bash

# script name: build-chroot.sh

############### set variables  ###################################################
source ./config

#symlink to 'build' directory is OK. TO DO: Next line needs (check for pwd else exit)
BUILDIR=$(pwd)
CHROOT=$BUILDIR/master/chroot
CD=$BUILDIR/master/cd
FORMAT=squashfs
FS_DIR=live

#buildscripts for the chroot
SCRIPTS=$BUILDIR/master/scripts

#possible opts:--variant=minbase exclude=aptitude,tasksel,tasksel-data --include=mc
BOOTSTRAPOPTS="--exclude=tasksel,tasksel-data"

#colours
red="[1;31m"
yel="[1;33m"
vi="[1;34m"
bl="[1;36m"
pk="[1;35m"
wt="[1;39m"

################################################################################
echo "$yel This script set will build a Debian 'chroot' and prepare it for a live CD."

# check for root
	if [[ $EUID -ne 0 ]]; then
	   echo "$red Only root may run this script." 1>&2
	tput sgr0
  	 exit 1
	fi

#check shell for correct current working directory
	if [ $(basename `pwd`) = 'build' ]; then 
	echo '......................................'
	else 
	echo "$red You have not called me from the 'build' directory. Try again."
	tput sgr0
	exit 
	fi

echo
echo "$yel Coloured text $vi is used, $pk displays best in $bl white-on-black terminal $yel"
echo
echo "$yel This is experimental software. Your system can be $red BUGGERED BEYOND REPAIR $yel if anything goes wrong."
echo
echo "     Read carefully the notes above.$red Continue? $yel (n to exit)	 <y/n>	"
tput sgr0

read REPLY

if [ "$REPLY" = "y" ]; then
echo
echo "continuing.........."
echo
else
exit
fi

#############################################################

echo "$yel Debian Apt sources are set to $DEBIAN_APTMODE"
echo " Dist is set to $DIST"
echo 
tput sgr0

# get apt sources sorted now

if [ "$DEBIAN_APTMODE" = "proxy" ]; then

cat > $SCRIPTS/sources.list <<EOF
##debian sources for approx
deb $PROXYURL/debian $DIST main contrib non-free
deb-src $PROXYURL/debian $DIST main contrib non-free

EOF

DEBURL=$PROXYURL/debian

else
cat > $SCRIPTS/sources.list <<EOF
deb http://ftp.$LOCALE.debian.org/debian/ $DIST main contrib non-free
deb-src http://ftp.$LOCALE.debian.org/debian/ $DIST main contrib non-free

EOF

DEBURL=http://ftp.$LOCALE.debian.org/debian

fi

if [ "$DIST" = "squeeze" ]; then
cat >> $SCRIPTS/sources.list <<EOF
# squeeze security and updates
deb http://security.debian.org/ squeeze/updates main contrib non-free
deb http://ftp.debian.org/debian/ squeeze-updates main contrib non-free

EOF
fi

if [ ! "$NONFREE" = "yes" ]; then
sed -i 's/main contrib non-free/main/'g $SCRIPTS/sources.list
fi
##############################################################################

echo
echo "$yel Get debbootstrap from $DIST? (n if exists already)	 <y/n>	"
read REPLY

			if [ "$REPLY" = "y" ]; then
			echo "............................................................"
			echo
tput sgr0
			debootstrap $BOOTSTRAPOPTS $DIST $CHROOT $DEBURL
			fi

#gets network up
cp -ax /etc/hosts $CHROOT/etc

#wont resolve if copied as a link
#cp -ax /etc/resolv.conf $CHROOT/etc
#try this (what to do if resolvconf installs?)
cp -ax /lib/init/rw/resolvconf/resolv.conf $CHROOT/etc

#chmode the main scripts
chmod 744 $BUILDIR/build-iso.sh $BUILDIR/chroot-smxi.sh $BUILDIR/enter-chroot.sh $BUILDIR/fix-umount.sh $BUILDIR/purge-buildir.sh

# sort chroot scripts
# and copy the config file there
cp -a $BUILDIR/config $SCRIPTS
#and our custom stuff
cp -ar $BUILDIR/custom $SCRIPTS/

find $SCRIPTS -type f -exec chmod 644 {} \;
find $SCRIPTS -type d -exec chmod 755 {} \;

cp -ax $SCRIPTS $CHROOT

chown -R root:root $CHROOT/scripts

# put sources.list in 
cp -ax $SCRIPTS/sources.list $CHROOT/etc/apt/sources.list

chmod -R 744 $CHROOT/scripts/*.sh
chmod -R 744 $CHROOT/scripts/custom/chrootscripts/*.sh
#chmod -R 744 $CHROOT/scripts/update-grubmod

#######################################################

	echo "$yel Enter chroot and execute chrootmod.sh (basic configs, kernel, preset kicklists) ?	<y/n>	"

	read REPLY

	if [ "$REPLY" = "y" ]; then

	echo
	tput sgr0

	
	mount -t proc proc $CHROOT/proc
	mount -t sysfs sysfs $CHROOT/sys
	mount -t devpts none $CHROOT/dev/pts
	mount -o bind /dev/ $CHROOT/dev

	chroot $CHROOT ./scripts/chroot-mod.sh
	tput sgr0
	fi

sleep 3

##########################################################################
echo "$yel Trying to unmount /proc/and /dev"
tput sgr0
echo

#normalise resolvconf
rm -f $CHROOT/etc/resolv.conf
cp -a $CHROOT/etc/resolv.conf.link $CHROOT/etc/resolv.conf

#move package list out
mv $CHROOT/manifest.txt $CD/manifest.txt
echo
umount $CHROOT/proc
umount $CHROOT/sys
umount $CHROOT/dev/pts
umount $CHROOT/dev

echo
sleep 3
umount $CHROOT/proc
umount $CHROOT/sys
umount $CHROOT/dev/pts
umount $CHROOT/dev

echo
echo "$red If you get 'device busy' warning above the chroot failed to unmount. Do not continue till fixed"
tput sgr0
echo
echo "DONE"
