#!/bin/bash
#
# script name: build-iso.sh
# script location: 'build/'
# prepares a Debian chroot for livecd, builds squashfs then a iso
#
####################################################################

# Get editable vars from config file.

source ./config

##########################################

BUILDIR=$(pwd) #the current working directory
CD=$BUILDIR/master/cd
SCRIPTS=$BUILDIR/master/scripts
CHROOT=$BUILDIR/master/chroot
#colours
red="[1;31m"
yel="[1;33m"
vi="[1;34m"
pk="[1;35m"
bl="[1;36m"
wt="[1;39m"
#
######################################################################
echo # space the text out
echo "$yel This script will clean up the chroot, then build the squashfs and Live ISO."
echo #
# check for root
if [[ $EUID -ne 0 ]]; then
   echo "buildiso.sh: Must be run as root." 1>&2
   exit 1
fi
#
	#check shell for correct current working directory
	if [ $(basename `pwd`) = 'build' ]; then 
	echo '......................................'
	else 
	echo "$red Script must only be called from the 'build' directory. Try again."
	tput sgr0
	exit 
	fi
echo 

echo "Trying to unmount chroot's /proc and /dev"
echo
tput sgr0
echo

PROCSTATE=$(umount $CHROOT/proc 2>&1 | sed -e 's/^.*: //' -e 's/ //g' -e '1!d')
SYSSTATE=$(umount $CHROOT/sys 2>&1 | sed -e 's/^.*: //' -e 's/ //g' -e '1!d')
DEVSTATE=$(umount $CHROOT/dev 2>&1 | sed -e 's/^.*: //' -e 's/ //g' -e '1!d')

if [ "$PROCSTATE" = "deviceisbusy" ]; then
echo "$red /proc is still busy in the chroot. It is unsafe to continue till fixed"
tput sgr0
exit

elif [ "$SYSSTATE" = "deviceisbusy" ]; then
echo "/$red sys is still busy in the chroot. It is unsafe to continue till fixed"
tput sgr0
exit

elif [ "$DEVSTATE" = "deviceisbusy" ]; then
echo "$red /dev is still busy in the chroot. It is unsafe to continue till fixed"
tput sgr0
exit

else
echo "Chroot sucessfully unmounted. Continuing."

fi

umount $CHROOT/proc
umount $CHROOT/sys
umount $CHROOT/dev/pts
umount $CHROOT/dev
#
echo "$yel If any 'device busy' warnings are listed above, $red DO NOT CONTINUE till fixed.  Exit now, then run './fix-umount.sh ' and/or reboot"
read -p "$yel  Continue? (n to exit)	<y/n>	"
tput sgr0
#
	if [ "$REPLY" = "y" ]; then
	tput sgr0
	else
	exit
fi
#delete these

for i in "$CHROOT/etc/hosts $CHROOT/etc/hostname $CHROOT/etc/timezone $CHROOT/etc/fstab $CHROOT/etc/mtab $CHROOT/etc/shadow $CHROOT/etc/shadow- $CHROOT/etc/gshadow  $CHROOT/etc/gshadow- $CHROOT/etc/gdm/gdm-cdd.conf $CHROOT/etc/gdm/gdm.conf-custom $CHROOT/etc/X11/xorg.conf $CHROOT/boot/grub/menu.lst $CHROOT/boot/grub/device.map"
do
	rm $i
	done 2>/dev/null

#################################
#not got this right yet
rm -f $CHROOT/etc/resolv.conf
cp -ax $CHROOT/etc/resolv.conf.link $CHROOT/etc/resolv.conf
##rm -f $CHROOT/etc/resolv.conf
##############################################

rm -f $CHROOT/root/.bash_history
rm -f $CHROOT/boot/*.bak
rm -rf $CHROOT/tmp/*
#and these **might be others in here
rm -f $CHROOT/etc/udev/rules.d/70-persistent*

rm -rf $CHROOT/etc/cups/ssl/server.crt
rm -rf $CHROOT/etc/cups/ssl/server.key
rm -rf $CHROOT/etc/ssh/ssh_host_rsa_key
rm -rf $CHROOT/etc/ssh/ssh_host_dsa_key.pub
rm -rf $CHROOT/etc/ssh/ssh_host_dsa_key
rm -rf $CHROOT/etc/ssh/ssh_host_rsa_key.pub

#saves lots of space; 'apt-get update' rebuilds it anyway

ls $CHROOT/var/lib/apt/lists | grep -v ".gpg" | grep -v "lock" | grep -v "partial" | xargs -i rm $CHROOT/var/lib/apt/lists/{} ; 

rm -f $CHROOT/var/cache/apt/srcpkgcache.bin $CHROOT/var/cache/apt/pkgcache.bin

#forgot apt-get clean in manual chroot session?
rm -f $CHROOT/var/cache/apt/archives/*.deb

find $CHROOT/var/run $CHROOT/var/log $CHROOT/var/mail $CHROOT/var/spool $CHROOT/var/lock $CHROOT/var/backups $CHROOT/var/tmp $CHROOT/var/crash $CHROOT/var/log/apt $CHROOT/var/log/cups $CHROOT/var/log/exim4 -type f -exec rm {} \;

for i in dpkg.log lastlog mail.log syslog auth.log daemon.log faillog lpr.log mail.warn user.log boot debug mail.err messages wtmp bootstrap.log dmesg kern.log mail.info
do
        touch $CHROOT/var/log/${i}
done

#
#sort final Debian sources.list and sources.list.d
rm -f $CHROOT/etc/apt/sources.list

cat > $CHROOT/etc/apt/sources.list <<EOF
#sources.list

##debian
deb http://ftp.$LOCALE.debian.org/debian/ $DIST main contrib non-free
#deb-src http://ftp.$LOCALE.debian.org/debian/ $DIST main contrib non-free

EOF

if [ "$DIST" = "squeeze" ]; then
cat >> $CHROOT/etc/apt/sources.list <<EOF 
# squeeze security and updates
deb http://security.debian.org/ squeeze/updates main contrib non-free
deb http://ftp.debian.org/debian/ squeeze-updates main contrib non-free

EOF
fi

# add debian-multimedia
echo "deb http://www.debian-multimedia.org/ $DIST main non-free " > $CHROOT/etc/apt/sources.list.d/debian-multimedia.list
echo "deb-src http://www.debian-multimedia.org/ $DIST main non-free " >> $CHROOT/etc/apt/sources.list.d/debian-multimedia.list

# disable all non-Debian repos except trinity
for i in $(ls $CHROOT/etc/apt/sources.list.d/*.list) ; do mv $i $i.disabled; done

# if using trinity, remake trinity.list
if [ -d "$CHROOT/opt/trinity" ]; then

rm -f $CHROOT/etc/apt/sources.list.d/trinity.list*

cat > $CHROOT/etc/apt/sources.list.d/trinity.list <<EOF

##trinity-desktop (3.5.13)
deb http://ppa.quickbuild.pearsoncomputing.net/trinity/trinity-v3.5.13/debian squeeze main
deb-src http://ppa.quickbuild.pearsoncomputing.net/trinity/trinity-v3.5.13/debian squeeze main
deb http://ppa.quickbuild.pearsoncomputing.net/trinity/trinity-builddeps-v3.5.13/debian squeeze main
deb-src http://ppa.quickbuild.pearsoncomputing.net/trinity/trinity-builddeps-v3.5.13/debian squeeze main

EOF
fi

chown root:root $CHROOT/etc/apt/sources.list $CHROOT/etc/apt/sources.list.d/*
#
#copy back menu.lts from chroot in case it changed for gfx-boot
cp -a $CHROOT/scripts/menu.lst $SCRIPTS/menu.lst

cp -a custom/skel $CHROOT/etc/

chown -R root:root $CHROOT/etc/skel

cp -a custom/message.hd $CHROOT/boot
chown root:root $CHROOT/boot/message.hd

############# Prepare CD directory ########################

#clear files from any previous build
rm -f $CD/md5sum.txt
		rm -f $CD/boot/*
		rm -f $CD/boot/grub/*
#
#Copy boot files from chroot:
#
VERSION=$( ls $CHROOT/boot | grep vmlinuz | sed "s/vmlinuz-//" )
#
cp -dRv $CHROOT/boot/vmlinuz-$VERSION $CD/boot/vmlinuz
cp -dRv $CHROOT/boot/initrd.img-$VERSION $CD/boot/initrd.gz
cp -dRv $CHROOT/boot/memtest86+.bin $CD/boot
cp -dRv $CHROOT/boot/message.hd $CD/boot
cp -dRv $CHROOT/packages.txt $CD/
#
#Copy grub's boot file stage2_eltorito #what to do about grub2 ??
find /boot /usr/lib/grub/ -iname 'stage2_eltorito' -exec cp -v {} $CD/boot/grub \;
#
#copy the prepared menu.lst for the cd
cp -diRv $SCRIPTS/menu.lst $CD/boot/grub/menu.lst
#
#delete scripts in chroot
rm -r $CHROOT/scripts
rm -f $CHROOT/packages.txt

##################################

# make the squash
	read -p "$yel make squashfs? ('n' to use existing)	<y/n>	"
	tput sgr0
	if [ "$REPLY" = "y" ]; then
	rm -f $CD/live/filesystem.squashfs
	mksquashfs $CHROOT $CD/live/filesystem.squashfs
	fi

################################################################
# md5sums
cd $CD && find . -type f -print0 | xargs -0 md5sum | tee $CD/md5sum.txt
#
#########################################################

# make new iso

# rename and date any previous iso
mv $BUILDIR/live-cd.iso $BUILDIR/live-cd`date '+%y%m%d_%H%M'`.iso
mv $BUILDIR/md5sum.txt $BUILDIR/md5sum`date '+%y%m%d_%H%M'`.txt

genisoimage -b boot/grub/stage2_eltorito -no-emul-boot -boot-load-size 4 -boot-info-table -V "dzbootstrap live cd" -cache-inodes -r -J -l -o $BUILDIR/live-cd.iso $CD

md5sum $BUILDIR/live-cd.iso >$BUILDIR/md5sum.txt
chmod 666 $BUILDIR/live-cd.iso
chmod 666 $BUILDIR/md5sum.txt
#
echo "$yel DONE build/live-cd.iso is ready"
tput sgr0
