#!/bin/bash
#
# script name: chroot-mod.sh
# script location: build/master/scripts (gets copied to /scripts in chroot)
#
########## run ONLY in the chroot else your main system gets BUGGERED#######
#
#set variables 

source /scripts/config

SCRIPTS=/scripts
KICKLISTS=$SCRIPTS/kicklists
#
#text colours
red="[1;31m"
yel="[1;33m"
vi="[1;34m"
bl="[1;36m"
pk="[1;35m"
#
########################################
#
# Check for root
if [ `id -u` != "0" ]; then
	echo "This script must be run as root. You are not root."
	exit 1
fi
#
	# check for bootstrap chroot session (/home will be empty if so)
	if [ $(ls -1A /home | wc -l) -eq 0 ]; then 
	tput sgr0
	echo "We APPEAR to now be in a chroot session"
	echo 
	echo "$red WARNING! If this is not so, your main system gets BUGGERED! "
	else
	tput sgr0
	echo "This seems to be NOT a chroot session! To save your running system from being TERMINALLY BUGGERED the script will now exit."
	exit
	fi
#
echo 
#final warning
echo " Continue?	 <y/n> "
read REPLY
#read -p " Continue?	 <y/n> "
#
	if [ "$REPLY" = "y" ]; then
	echo
	else
	exit
	fi
#
#resets terminal font colour
tput sgr0
#
#sort apt language and locales
LANG=


#fix install and temporarily override resolvconf
apt-get update
apt-get -d install resolvconf
rm -f /etc/resolv.conf
apt-get -y --force-yes install resolvconf
#
#save the symlink for later
cp -ax /etc/resolv.conf /etc/resolv.conf.link
#
#get resolvconf going with opendns
rm -f /etc/resolv.conf
touch /etc/resolv.conf
echo "nameserver 208.67.222.222" > /etc/resolv.conf
echo "nameserver 208.67.220.220" >> /etc/resolv.conf
cp -ax /etc/resolv.conf /etc/resolv.conf.opendns

apt-get update
apt-get -y --force-yes install debian-archive-keyring
apt-get -y --force-yes install locales
dpkg-reconfigure locales
#
##################################
#do the kernel

#prevent initrd warnings
echo "# Kernel Image management overrides" >> /etc/kernel-img.conf
echo "# See kernel-img.conf(5) for details" >> /etc/kernel-img.conf
echo "do_symlinks = Yes" >> /etc/kernel-img.conf
echo "warn_initrd = No" >> /etc/kernel-img.conf

if [ "$KERNEL" = "debian" ] ; then
#
apt-get -y --force-yes install linux-image-2.6-686
#
#update-grub fails in chroot with squeeze kernel install and chokes apt: Disable it

mv /etc/kernel/postinst.d/zz-update-grub /
#
#now fix the apt error
#?dpkg-reconfigure linux-image-2.6-686?
apt-get -f install
#normalise zz-update-grub
mv /zz-update-grub /etc/kernel/postinst.d
#
apt-get -y --force-yes install linux-headers-2.6-686

fi

if [ "$KERNEL" = "liquorix" ] ; then

touch /etc/apt/sources.list.d/liquorix.list
echo 'deb http://liquorix.net/debian/ sid main' > /etc/apt/sources.list.d/liquorix.list
apt-get update
apt-get -y --force-yes install liquorix-archive-keyring
apt-get -y --force-yes install linux-image-2.6-liquorix-686
mv /etc/kernel/postinst.d/zz-update-grub /
apt-get -f install
mv /zz-update-grub /etc/kernel/postinst.d
apt-get -y --force-yes install linux-headers-2.6-liquorix-686

fi

#install grub-legacy
	#keep out grub2....we can't deal with it yet
	if [ "$DIST" = "lenny" ]; then
	GRUB=grub
	else
	GRUB=grub-legacy
	fi
#
apt-get -y --force-yes install $GRUB

#########################################################################################################
#
apt-get -y --force-yes install console-data gpm
#
#these are out in squeeze
#apt-get -y --force-yes install squashfs-modules-2.6-686
#apt-get -y --force-yes install aufs-modules-2.6-686
# not in squeeze
#apt-get -y --force-yes install discover1
#


apt-get -y --force-yes install xresprobe
#

############## live-initramfs seems broken in squeeze so

#live-initramfs: Depends: busybox, file, initramfs-tools, sudo, udev, user-setup


#fi
if [ "$DIST" = "lenny" ]; then
apt-get -y --force-yes install live-initramfs
else
apt-get -y --force-yes install live-boot live-config
fi

########################################################
#
#uname-r doesn't work as expected in chroot so get $VERSION this way.....
VERSION=$(ls /boot | grep vmlinuz| sed "s/vmlinuz-//")
depmod -a $VERSION
#-----------------------------------------------------------------------

#==============================================================================
#fam makes chroot apt errors. It will get pulled in anyway so install now then stop its daemon
apt-get -y install fam
/etc/init.d/fam stop
#
apt-get $APTCLEAN
#check for errors and missing packages in these kicklists. apt might give up if any one is missing then we must edit and rerun the list
	for i in $( cat $KICKLISTS/kicklist-base )
	do
	apt-get -y --force-yes install $i
	done
#

	if [ ! "$CONSOLEONLY" = "yes" ]; then
	#
	for i in $( cat $KICKLISTS/kicklist-xapps )
	do
	apt-get -y --force-yes install $i
	done
	fi

# no-recommends e.g. qt4 stuff
#for i in x y z ; do
apt-get -y --force-yes --no-install-recommends install wpagui

################################################## REMASTERSYS NOW FORCES GRUB2 AND LIVE-BOOT ################

#get remastersys for our installer
if [ "$DIST" = "lenny" ]; then

touch /etc/apt/sources.list.d/remastersys.list
echo "deb http://www.geekconnection.org/remastersys/repository debian/" > /etc/apt/sources.list.d/remastersys.list

apt-get update
apt-get -y --force-yes install remastersys

apt-get $APTCLEAN
rm -f /etc/apt/sources.list.d/remastersys.list
apt-get update
echo

#else
#echo "deb http://www.geekconnection.org/remastersys/repository squeeze/" >> /etc/apt/sources.list
#touch /etc/apt/sources.list.d/remastersys.list
#echo "deb http://www.geekconnection.org/remastersys/repository squeeze/" > /etc/apt/sources.list.d/remastersys.list

#use custom remastersys for grub-legacy
fi

########################################################################
#
	if [ "$DESKTOP" = "kde3" ]; then

		if [ "$DIST" = "lenny" ]; then
		apt-get install kde-core
		echo
		for i in $( cat $KICKLISTS/kicklist-kde3 )
		do
		apt-get -y --force-yes install $i
		done

			else
			echo "Error...kde3 supported only for Lenny"
		fi
#	
	elif [ "$DESKTOP" = "kde4" ]; then
	apt-get install kde-core
	echo 
	for i in $( cat $KICKLISTS/kicklist-kde4 )
	do
	apt-get -y --force-yes install $i
	done
#
	elif [ "$DESKTOP" = "lxde" ]; then
	apt-get install lxde
	echo 
	for i in $( cat $KICKLISTS/kicklist-lxde )
	do
	apt-get -y --force-yes install $i
	done
	#
	elif [ "$DESKTOP" = "xfce" ]; then
	apt-get -y --force-yes install xfce4
	echo 
	for i in $( cat $KICKLISTS/kicklist-xfce )
	do
	apt-get -y --force-yes install $i
	done
#
	elif [ "$DESKTOP" = "trinity" ]; then

#############################################
if [ "$TRINITY_APTMODE" = "approx" ]; then

touch /etc/apt/sources.list.d/trinity.list
cat > /etc/apt/sources.list.d/trinity.list <<EOF
##trinity sources for approx
deb $PROXYURL/trinity squeeze main
deb-src $PROXYURL/trinity squeeze main
deb $PROXYURL/trinity-builddeps squeeze main
deb-src $PROXYURL/trinity-builddeps squeeze main
EOF

else

	if [ "$TRINITY_SOURCES" = "svn" ]; then

# use nightly builds
touch /etc/apt/sources.list.d/trinity-nightly-builds.list
cat > /etc/apt/sources.list.d/trinity-nightly-builds.list <<EOF

##trinity-nightly-builds sources for approx
deb http://ppa.quickbuild.pearsoncomputing.net/trinity/trinity-nightly-builds/debian/ squeeze main
deb-src http://ppa.quickbuild.pearsoncomputing.net/trinity/trinity-nightly-builds/debian/ squeeze main
deb http://ppa.quickbuild.pearsoncomputing.net/trinity/trinity-nightly-build-dependencies/debian/ squeeze main
deb-src http://ppa.quickbuild.pearsoncomputing.net/trinity/trinity-nightly-build-dependencies/debian/ squeeze main

EOF

	else

touch /etc/apt/sources.list.d/trinity.list
cat > /etc/apt/sources.list.d/trinity.list <<EOF
##trinity sources for approx
deb http://ppa.quickbuild.pearsoncomputing.net/trinity/trinity-v3.5.13/debian squeeze main
deb-src http://ppa.quickbuild.pearsoncomputing.net/trinity/trinity-v3.5.13/debian squeeze main
deb http://ppa.quickbuild.pearsoncomputing.net/trinity/trinity-builddeps-v3.5.13/debian squeeze main
deb-src http://ppa.quickbuild.pearsoncomputing.net/trinity/trinity-builddeps-v3.5.13/debian squeeze main
EOF

	fi

fi

#########################################
#
	apt-key adv --keyserver keyserver.quickbuild.pearsoncomputing.net --recv-keys 2B8638D0
	apt-get update

	apt-get -y --force-yes install --allow-unauthenticated trinity-keyring
	echo 
	for i in $( cat $KICKLISTS/kicklist-kde-trinity )
	do

	# TODO watch out here.. force-yes might be dodgy with trinity mirrors
	#apt-get -y --force-yes install $i	# might not have keyring for svn
	apt-get -y --force-yes install --allow-unauthenticated $i
	done
	echo
	echo "Appying fixes for Trinity Desktop"
	#fix kdmrc
	sed -i 's:Theme=/usr/share/apps/kdm/themes/debian-moreblue:Theme=/opt/trinity/share/apps/kdm/themes/o2_enterprise:g' /etc/trinity/kdm/kdmrc

	sed -i 's:#TerminateServer=true:TerminateServer=true:' /etc/trinity/kdm/kdmrc
	
		#libnjb5 in squeeze gives sysfs errors
		if [ -e "/etc/udev/libnjb.rules" ]; then
		sed -i 's|SYSFS|ATTR|'g /etc/udev/libnjb.rules
		fi
	# fix sudo-trinity.. it was not cleanly installed because we have no root passwd
	export SUDO_FORCE_REMOVE=yes
	apt-get -y --force-yes install --reinstall sudo-trinity
	export SUDO_FORCE_REMOVE=""
	#
	fi
#
# fallback desktop
if [ ! "$DESKTOP2" = "" ]; then
apt-get -y --force-yes install $DESKTOP2

# lxde install will set itself default dm so
echo "/opt/trinity/bin/kdm" > /etc/X11/default-display-manager
fi

#installing fallback desktop probably changed defaults to itself, so
if [ -e /opt/trinity/bin/kdm ]; then
update-alternatives --set x-terminal-emulator /opt/trinity/bin/konsole
update-alternatives --set x-window-manager /opt/trinity/bin/kwin
update-alternatives --set x-session-manager /opt/trinity/bin/startkde
fi
##########################################################

apt-get update
apt-get $APTCLEAN

############################################################

if [ "$MULTIMEDIA" = "yes" ]; then

echo
for i in $( cat $KICKLISTS/kicklist-multimedia )
do
apt-get -y --force-yes install $i
done
apt-get $APTCLEAN
fi

if [ "$MARILLAT" = "yes" ]; then

echo "deb http://www.debian-multimedia.org/ $DIST main non-free " > /etc/apt/sources.list.d/debian-multimedia.list
echo "deb-src http://www.debian-multimedia.org/ $DIST main non-free " >> /etc/apt/sources.list.d/debian-multimedia.list

apt-get update
apt-get -y --force-yes install debian-multimedia-keyring

	for i in libdvdcss2 libxvidcore4 avidemux mplayer mencoder w32codecs
	do
	apt-get -y --force-yes install $i
	done
	
rm -f /etc/apt/sources.list.d/debian-multimedia.list 
apt-get update

#fix debian-multimedia's broken ffmpeg
#apt-get -y --force-yes purge debian-multimedia-keyring
apt-get -y --force-yes purge libavutil*

for i in libquicktime1 libxine1-ffmpeg libxine1-plugins libk3b3-extracodecs-trinity ffmpeg audacious
do
apt-get -y --force-yes install $i
done

fi

###########################################################
#
echo

	if [ "$NONFREE" = "yes" ]; then

	echo
	apt-get update
	for i in $( cat $KICKLISTS/kicklist-nonfree )
	do
	apt-get -y install $i
	done
	apt-get $APTCLEAN
	fi
#
#################################################################################
#install smxi. You can't run it in X or without a /boot/grub/menu.lst
cd /usr/local/bin && wget http://techpatterns.com/smxi && chmod +x smxi && cd /
#################################################################################
#
#saves LOTS of space
#apt-get remove --purge aptitude
apt-get install localepurge
localepurge
apt-get $APTCLEAN
#

#sort custom stuff install and purge and more

for i in $( ls $SCRIPTS/custom/chrootscripts |grep .sh )
do
$SCRIPTS/custom/chrootscripts/$i
done

if [ "$INITDEFAULT" = "5" ]; then

echo "$yel Setting default runlevel to $INITDEFAULT"
tput sgr0

sed -i "s/id:[1-5]:initdefault:/id:$INITDEFAULT:initdefault:/" /etc/inittab /usr/share/sysvinit/inittab

	if [ -e /opt/trinity/bin/kdm ]; then
	sysv-rc-conf --level 012346 kdm-trinity off
	sysv-rc-conf --level 5$INITDEFAULT kdm-trinity on
	fi

		if [ -e /usr/bin/kdm ]; then
		sysv-rc-conf --level 012346 kdm off
		sysv-rc-conf --level 5 kdm on
		fi

			if [ -e /usr/bin/gdm ]; then
			sysv-rc-conf --level 012346 gdm off
			sysv-rc-conf --level 5 gdm on
			fi

fi

# dist-upgrade to security and updates repos
apt-get dist-upgrade

##################################################################

echo ""
echo "$yel Checking for packages no longer required................... "
echo ""
echo "$yel Running deborphan.$red Answer 'n' if unsure it really should be purged!"
tput sgr0
deborphan >deborphan
for i in $(cat deborphan); do apt-get purge $i; done

echo ""
echo "$yel Running apt-get autoremove.$red Answer 'n' if unsure it really should be purged!"
tput sgr0

# make a temp autoremove list else apt removes all of them at once 
apt-get autoremove -s |grep Remv |sed 's/Remv //'g | sed 's/ \[.*//'g > autoremove
for i in $(cat autoremove); do apt-get purge $i; done

# run it again
deborphan >deborphan
for i in $(cat deborphan); do apt-get purge $i; done
echo ""

# remove temp autoremove/deborphan lists
rm -f deborphan autoremove

# best to choose vga else you get terminus fonts
dpkg-reconfigure console-setup

#normalise resolvconf
rm -f $CHROOT/etc/resolv.conf
cp -a $CHROOT/etc/resolv.conf.link $CHROOT/etc/resolv.conf
#
#update modules and initrd
#
#if no version given tries to do running system kernel not the one in chroot.............
depmod -a $VERSION
# seems to work OK on chroot kernel without other options
update-initramfs -u
#
#get manifest.txt (installed package list)
dpkg -l|grep ii|awk '{print $2}' > manifest.txt
##
#these daemons might be running in chroot - stop them - maybe others - maybe nightmare to find them (then reboot)
#/etc/init.d/acpid stop
#/etc/init.d/atd stop
#/etc/init.d/avahi-daemon stop
#/etc/init.d/dbus stop
#/etc/init.d/cups stop
#/etc/init.d/ssh stop
#/etc/init.d/fam stop
#/etc/init.d/exim4 stop
#/etc/init.d/nfs-common stop
#/etc/init.d/portmap stop
#/etc/init.d/timidity stop
####/etc/init.d/dnsmasq stop
####/etc/init.d/mysql stop

for i in acpid atd avahi-daemon dbus cups ssh fam exim4 nfs-common portmap timidity; do
/etc/init.d/$i stop
done
#
echo "Closing chroot session"
#
# if using Trinity, en_GB and one extra language can fit a CD
echo "$yel Note: Extra language packs for the desktop will need manual installation"
tput sgr0
#fin
